Module ir
graphyn_
core
0.1.1
Module ir
Module Items
Structs
Enums
Type Aliases
In crate graphyn_
core
graphyn_core
Module
ir
Structs

FileIR
The complete IR output from one file parse.
Relationship
A directed relationship between two symbols.
RepoIR
The complete IR output from a full repo or incremental update.
Symbol
A symbol — any named entity in source code.
Enums

Language
Relationship
Kind
Symbol
Kind
Type Aliases

Symbol
Id
Unique identifier for a symbol across the entire codebase. Format: “relative/file/path.ts::SymbolName::kind” Example: “src/models/user.ts::UserPayload::class” Example: “src/models/user.ts::UserPayload::userId::property”