Module query

Module query 

Structs

QueryEdge

Functions

blast_radius
dependencies
is_renamed
True when edge refers to its target under a name other than the target’s.
partition_by_alias
Split edges into those that reach the symbol under its own name and those that rename it.
symbol_usages