pub fn is_renamed(graph: &GraphynGraph, edge: &QueryEdge) -> boolExpand description
True when edge refers to its target under a name other than the target’s.
pub fn is_renamed(graph: &GraphynGraph, edge: &QueryEdge) -> boolTrue when edge refers to its target under a name other than the target’s.