pub fn walk_source_files_reporting<F>(
root: &Path,
config: &ScanConfig,
is_supported: F,
) -> Result<ScanReport, Error>Expand description
Walk for source files, recording which directories the defaults pruned.
pub fn walk_source_files_reporting<F>(
root: &Path,
config: &ScanConfig,
is_supported: F,
) -> Result<ScanReport, Error>Walk for source files, recording which directories the defaults pruned.