Module ir

Module ir 

Structs

FileIR
The complete IR output from one file parse.
Relationship
A directed relationship between two symbols.
RepoIR
The complete IR output from a full repo or incremental update.
Symbol
A symbol — any named entity in source code.

Enums

Language
RelationshipKind
SymbolKind

Type Aliases

SymbolId
Unique identifier for a symbol across the entire codebase. Format: “relative/file/path.ts::SymbolName::kind” Example: “src/models/user.ts::UserPayload::class” Example: “src/models/user.ts::UserPayload::userId::property”